----------------------------------------------------------------
-- Source File Name: egffishl.db2
--
-- Licensed materials - Property of IBM
-- 5799-GXQ
-- (c) Copyright IBM Corp. 2003 All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or 
-- Disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
----------------------------------------------------------------
-- This file has the DDL statements to create the views that serve as
-- the interface for other tools using the DB2 Grouper component.

CREATE VIEW SYSTOOLS.EGF_DEFGROUPINGS
  (VERSIONNAME, GROUPNAME, TABSCHEMA, TABNAME, TBSPACE, GRPDSCYTIME, DSCYRUNBY) AS
     SELECT C.VERSIONNAME, B.GROUPNAME, A.TABSCHEMA, A.TABNAME, A.TBSPACENAME, C.GRPDSCYTIME, C.DSCYRUNBY 
       FROM SYSTOOLS.EGF_TABLES A, SYSTOOLS.EGF_GROUPS B, 
            SYSTOOLS.EGF_ALLWORKINGSETS C
          WHERE C.INFOID = (SELECT ID FROM 
                            SYSTOOLS.EGF_WORKINGSETINFO
                             WHERE SETNAME = 'CATALOGWIDE') AND
                C.AVAILABLE = 'Y' AND
                B.SETID = C.ID AND
                A.SETID = B.SETID AND
                A.GROUPID = B.ID AND
                A.REMOVED = 'N';
                
                


CREATE VIEW SYSTOOLS.EGF_GROUPINGS
  (SETNAME, VERSIONNAME, GROUPNAME, TABSCHEMA, TABNAME, TBSPACE, CRAWLTYPE, GRPDSCYTIME, DSCYRUNBY) AS
     SELECT C.SETNAME, D.VERSIONNAME, B.GROUPNAME, A.TABSCHEMA, A.TABNAME, A.TBSPACENAME, 
         D.CRAWLTYPE, D.GRPDSCYTIME, D.DSCYRUNBY
       FROM SYSTOOLS.EGF_TABLES A, SYSTOOLS.EGF_GROUPS B, 
            SYSTOOLS.EGF_WORKINGSETINFO C, SYSTOOLS.EGF_ALLWORKINGSETS D
          WHERE C.ID = D.INFOID AND
                D.INFOID IN (SELECT ID FROM 
                             SYSTOOLS.EGF_WORKINGSETINFO
                             WHERE NOT (SETNAME = 'CATALOGWIDE')) AND
                D.AVAILABLE = 'Y' AND
                B.SETID = D.ID AND
                A.SETID = B.SETID AND
                A.GROUPID = B.ID AND 
                A.REMOVED = 'N';
                

                                                         
CREATE VIEW SYSTOOLS.EGF_RELATIONS 
   (SETNAME, VERSIONNAME, GROUPNAME, RELTYPE, RELSUBTYPE, SCHEMANAME1,
    OBJECTNAME1, OBJECTTYPE1, SCHEMANAME2, OBJECTNAME2, OBJECTTYPE2,
    SOURCE, CONSTNAME) AS 
       (SELECT D.SETNAME, C.VERSIONNAME, B.GROUPNAME, A.RELTYPE, A.RELSUBTYPE, 
               A.SCHEMANAME1, A.OBJECTNAME1, A.OBJECTTYPE1, A.SCHEMANAME2, A.OBJECTNAME2,
               A.OBJECTTYPE2, A.SOURCE, A.CONSTNAME FROM 
                  SYSTOOLS.EGF_GROUPRELS A, SYSTOOLS.EGF_GROUPS B, SYSTOOLS.EGF_ALLWORKINGSETS C,
                  SYSTOOLS.EGF_WORKINGSETINFO D WHERE
                     C.ID IN (SELECT ID FROM 
                                   SYSTOOLS.EGF_ALLWORKINGSETS where AVAILABLE = 'Y') AND
                     D.ID = C.INFOID AND
                     B.SETID = C.ID AND
                     A.SETID = B.SETID AND
                     A.GROUPID = B.ID);
                     
 

CREATE VIEW SYSTOOLS.EGF_KEYCOLUSE ( CONSTNAME, COLSEQ, PTABSCHEMA, PTABNAME,
   PCOLNAME, PCOLTYPESCHEMA, PCOLTYPENAME, PSCALE, PLENGTH, CTABSCHEMA, CTABNAME,
   CCOLNAME, CCOLTYPESCHEMA, CCOLTYPENAME, CSCALE, CLENGTH         
   ) AS
     ((SELECT A.CONSTNAME, A.COLSEQ, E.TABSCHEMA, E.TABNAME, E.COLNAME, 
                F.TYPESCHEMA, F.TYPENAME, F.LENGTH, F.SCALE,
                A.TABSCHEMA, A.TABNAME, A.COLNAME, B.TYPESCHEMA, 
                B.TYPENAME, B.SCALE, B.LENGTH
                  FROM
                     SYSCAT.KEYCOLUSE A, SYSCAT.COLUMNS B, 
                     SYSCAT.KEYCOLUSE E, SYSCAT.COLUMNS F   
                     WHERE 
                     (A.CONSTNAME, A.TABSCHEMA, A.TABNAME, 
                      E.CONSTNAME, E.TABSCHEMA, E.TABNAME) IN 
                             (SELECT C.CONSTNAME, C.TABSCHEMA, C.TABNAME, C.REFKEYNAME, 
                                     C.REFTABSCHEMA, C.REFTABNAME FROM 
                                       SYSCAT.REFERENCES C, SYSTOOLS.EGF_RELATIONS D WHERE 
                                         C.CONSTNAME = D.CONSTNAME AND 
                                         C.REFTABSCHEMA = D.SCHEMANAME1 AND 
                                         C.REFTABNAME = D.OBJECTNAME1 AND 
                                         C.TABSCHEMA = D.SCHEMANAME2 AND 
                                         C.TABNAME = D.OBJECTNAME2) AND 
                      B.TABSCHEMA = A.TABSCHEMA AND 
                      B.TABNAME = A.TABNAME AND 
                      B.COLNAME = A.COLNAME AND 
                      F.TABSCHEMA = E.TABSCHEMA AND 
                      F.TABNAME = E.TABNAME AND 
                      F.COLNAME = E.COLNAME AND 
                      A.COLSEQ = E.COLSEQ ) UNION ALL
       (SELECT A.CONSTNAME, A.COLSEQ, A.PTABSCHEMA, A.PTABNAME,
               A.PCOLNAME, B.TYPESCHEMA, B.TYPENAME, B.SCALE, B.LENGTH,     
               A.CTABSCHEMA, A.CTABNAME, A.CCOLNAME, C.TYPESCHEMA, 
               C.TYPENAME, C.SCALE, C.LENGTH FROM
                  SYSTOOLS.EGF_UMRIKEYCOLUSE A, SYSCAT.COLUMNS B, 
                  SYSCAT.COLUMNS C WHERE
                      A.CONSTNAME in (SELECT CONSTNAME from SYSTOOLS.EGF_GROUPRELS  
                                        WHERE SETID IN 
                                           (SELECT ID FROM SYSTOOLS.EGF_ALLWORKINGSETS 
                                            WHERE AVAILABLE = 'Y')) AND
                      A.PTABSCHEMA = B.TABSCHEMA AND
                      A.PTABNAME = B.TABNAME AND  
                      A.PCOLNAME = B.COLNAME AND 
                      A.CTABSCHEMA = C.TABSCHEMA AND
                      A.CTABNAME = C.TABNAME AND
                      A.CCOLNAME = C.COLNAME ));


COMMIT;


